@@ -22,11 +22,11 @@ use IO::File;
 BEGIN {
 	use vars qw($prefix $datarootdir $datadir);
 	$prefix = "/usr/pkg";
-	$datarootdir = "${prefix}/share";
-	$datadir = "${datarootdir}";
+	$datarootdir = "/usr/pkg/share";
+	$datadir = "/usr/pkg/share";
 }
 
-use lib "${datadir}/fvwm3/perllib";
+use lib "/usr/pkg/share/fvwm3/perllib";
 use vars qw($VERSION @ISA @EXPORT $AUTOLOAD);
 
 use FVWM::Constants;
@@ -290,7 +290,7 @@ sub is_in_sync_mask ($$) {
 # by default the version of a module is the fvwm version
 sub version ($) {
 	my $self = shift;
-	return "1.0.4";
+	return "1.1.2";
 }
 
 sub version_info ($) {
@@ -666,7 +666,7 @@ sub user_data_dir ($) {
 }
 
 sub site_data_dir ($) {
-	return "${datadir}/fvwm3";
+	return "/usr/pkg/share/fvwm3";
 }
 
 sub search_dirs ($) {
@@ -1156,7 +1156,7 @@ Returns the user data directory, usually ~/.fvwm or set by $FVWM_USERDIR.
 =item B<site_data_dir>
 
 Returns the system-wide data directory, the one configured when fvwm is
-installed. It is also returned by `fvwm-config --fvwm-datadir`.
+installed.
 
 =item B<search_dirs>
 
